@@ -20,6 +20,21 @@ def run_collectstatic():
         run_workon('python2.7 manage.py collectstatic --noinput')
 
 
+@require_server
+def run_compilemessages():
+    """
+    Executes ./manage.py compilemessages on the server.
+
+    Usage::
+
+        fab <server name> run_compilemessages
+
+    """
+
+    with cd(settings.SERVER_PROJECT_ROOT):
+        run_workon('python2.7 manage.py compilemessages')
+
+
 @require_server
 def run_deploy_website(restart_apache=False):
     """
@@ -35,6 +50,10 @@ def run_deploy_website(restart_apache=False):
     run_rsync_project()
     run_syncdb()
     run_collectstatic()
+    if getattr(settings, 'MAKEMESSAGES_ON_DEPLOYMENT', False):
+        run_makemessages()
+    if getattr(settings, 'COMPILEMESSAGES_ON_DEPLOYMENT', False):
+        run_compilemessages()
     if restart_apache:
         run_restart_apache()
     else:
@@ -131,6 +150,20 @@ def run_git_pull():
         run('git pull && git submodule init && git submodule update')
 
 
+@require_server
+def run_makemessages():
+    """
+    Executes ./manage.py makemessages -s --all on the server.
+
+    Usage::
+
+        fab <server name> run_makemessages
+
+    """
+    with cd(settings.SERVER_PROJECT_ROOT):
+        run_workon('python2.7 manage.py makemessages -s --all')
+
+
 @require_server
 def run_pip_install(upgrade=0):
     """
